#[non_exhaustive]pub enum ArtifactDependencyNode {
Volume(Identifier),
ImageAcquisition(Identifier),
ImageBuild(Identifier),
}Expand description
A format-neutral node used by explicit image-artifact dependency validation.
Native adapters create values only after they have established a typed reference. This model does not parse native raw argument or mount spellings to invent an edge.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Volume(Identifier)
One application volume.
ImageAcquisition(Identifier)
One image-acquisition resource.
ImageBuild(Identifier)
One image-build resource.