#[non_exhaustive]pub enum BuildSourceDeclaration {
Scalar(ProtectedString),
Structured(Vec<Sourced<SourceBuildSetting>>),
}Expand description
One source declaration for an image build.
A scalar context is not silently expanded into a structured declaration. Structured declarations retain field order, duplicate fields, and explicitly present empty per-key collections.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Scalar(ProtectedString)
Short scalar context syntax.
Structured(Vec<Sourced<SourceBuildSetting>>)
Structured declaration syntax.
Implementations
Sourceimpl BuildSourceDeclaration
impl BuildSourceDeclaration
Sourcepub const fn syntax(&self) -> BuildSyntax
pub const fn syntax(&self) -> BuildSyntax
Returns the preserved source syntax family.
Sourcepub fn structured_settings(&self) -> Option<&[Sourced<SourceBuildSetting>]>
pub fn structured_settings(&self) -> Option<&[Sourced<SourceBuildSetting>]>
Returns structured settings in source order when this is a structured declaration.