ModelError

Enum ModelError 

#[non_exhaustive]
pub enum ModelError {
Show 19 variants EmptyValue(&'static str), ContainsNul(&'static str), ReversedSpan { start: usize, end: usize, }, DuplicateResource { kind: &'static str, name: String, }, DuplicateServiceGroupMember { group: String, service: String, }, UnknownServiceGroupMember { group: String, service: String, }, ServiceInMultipleGroups { service: String, existing: String, replacement: String, }, UnknownImageAcquisitionReference { service: String, acquisition: String, }, UnknownImageBuildReference { service: String, build: String, }, UnknownVolumeImageAcquisitionReference { volume: String, acquisition: String, }, UnknownVolumeImageBuildReference { volume: String, build: String, }, UnknownArtifactDependencyNode { kind: &'static str, name: String, }, ImageArtifactDependencyCycle { nodes: Vec<String>, }, InvalidImageReference(&'static str), ZeroContainerPort, UnknownNetworkAttachmentIndex { index: usize, len: usize, }, UnknownServiceGroupRuntimeNetworkIndex { index: usize, len: usize, }, RootfsImageSourceConflict { service: String, source: &'static str, }, InvalidHealthcheckRetries,
}
Error raised when constructing an invalid neutral model value.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyValue(&'static str)

A required value was empty.



ContainsNul(&'static str)

A value contained a NUL byte.



ReversedSpan

A source byte range ended before it started.

Fields

start: usize

Inclusive start offset.

end: usize

Exclusive end offset.



DuplicateResource

An application already contains a resource of this kind and name.

Fields

kind: &'static str

Neutral resource kind.

name: String

Duplicated name.



DuplicateServiceGroupMember

A service was added to the same group more than once.

Fields

group: String

Service-group name.

service: String

Duplicate service name.



UnknownServiceGroupMember

A service group referenced a service absent from the application.

Fields

group: String

Service-group name.

service: String

Missing service name.



ServiceInMultipleGroups

A service was assigned to more than one application group.

Fields

service: String

Service name.

existing: String

Existing service-group name.

replacement: String

Conflicting service-group name.



UnknownImageAcquisitionReference

A service referenced an image acquisition absent from the application.

Fields

service: String

Referencing service name.

acquisition: String

Missing image-acquisition resource name.



UnknownImageBuildReference

A service referenced an image build absent from the application.

Fields

service: String

Referencing service name.

build: String

Missing image-build resource name.



UnknownVolumeImageAcquisitionReference

A volume referenced an image-acquisition resource absent from the application.

Fields

volume: String

Referencing volume name.

acquisition: String

Missing image-acquisition resource name.



UnknownVolumeImageBuildReference

A volume referenced an image-build resource absent from the application.

Fields

volume: String

Referencing volume name.

build: String

Missing image-build resource name.



UnknownArtifactDependencyNode

An explicitly supplied artifact dependency referred to a resource absent from the application.

Fields

kind: &'static str

Missing resource kind.

name: String

Missing resource name.



ImageArtifactDependencyCycle

Explicit artifact dependencies formed a cycle.

Fields

nodes: Vec<String>

Stable, resource-qualified members of one detected cycle.



InvalidImageReference(&'static str)

An image reference had invalid component structure.



ZeroContainerPort

A container port was zero.



UnknownNetworkAttachmentIndex

A requested service network-attachment index did not exist.

Fields

index: usize

Requested attachment index.

len: usize

Number of attachments present when replacement was attempted.



UnknownServiceGroupRuntimeNetworkIndex

A requested group-runtime network-attachment index did not exist.

Fields

index: usize

Requested attachment index.

len: usize

Number of attachments present when replacement was attempted.



RootfsImageSourceConflict

A service combined a root filesystem with an image source.

Fields

service: String

Referencing service name.

source: &'static str

Conflicting image source kind.



InvalidHealthcheckRetries

A health-check retry count was not a non-negative decimal integer.