#[non_exhaustive]pub enum ResourceOwnership {
Application,
External,
Implicit,
Uncertain,
}Expand description
Who owns a named application resource lifecycle.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Application
The application declares and owns the resource.
External
The target environment owns the resource outside this application.
Implicit
A source implementation supplied the resource implicitly.
Uncertain
Runtime inspection established the resource but not who should manage its lifecycle.