pub struct BuildContext { /* private fields */ }Expand description
One named additional context in a structured source build declaration.
Implementations
Sourceimpl BuildContext
impl BuildContext
Sourcepub const fn new(name: ProtectedString, value: ProtectedString) -> Self
pub const fn new(name: ProtectedString, value: ProtectedString) -> Self
Creates a named additional build context without applying native rules.
Sourcepub const fn name(&self) -> &ProtectedString
pub const fn name(&self) -> &ProtectedString
Returns the declared context name.
Sourcepub const fn value(&self) -> &ProtectedString
pub const fn value(&self) -> &ProtectedString
Returns the raw-preserving context value.