Healthcheck

Struct Healthcheck 

pub struct Healthcheck { /* private fields */ }
Format-independent service health-check intent with field-level provenance.

Implementations

Source

impl Healthcheck

pub const fn new() -> Self

Creates an empty health-check definition for incremental source-adapter mapping.

pub fn set_command(&mut self, command: Sourced<HealthcheckCommand>)

Sets the command executed by the runtime.

pub const fn command(&self) -> Option<&Sourced<HealthcheckCommand>>

Returns the optional health command.

pub fn set_disabled(&mut self, disabled: Sourced<bool>)

Retains an explicit enable/disable decision.

pub const fn disabled(&self) -> Option<&Sourced<bool>>

Returns the explicit disable decision, if the source supplied one.

pub fn set_interval(&mut self, interval: Sourced<HealthcheckDuration>)

Sets the interval between regular checks.

pub const fn interval(&self) -> Option<&Sourced<HealthcheckDuration>>

Returns the interval between regular checks.

pub fn set_timeout(&mut self, timeout: Sourced<HealthcheckDuration>)

Sets the maximum duration of one check.

pub const fn timeout(&self) -> Option<&Sourced<HealthcheckDuration>>

Returns the maximum duration of one check.

pub fn set_retries(&mut self, retries: Sourced<HealthcheckRetries>)

Sets the number of failures required before becoming unhealthy.

pub const fn retries(&self) -> Option<&Sourced<HealthcheckRetries>>

Returns the failure threshold.

pub fn set_start_period(&mut self, start_period: Sourced<HealthcheckDuration>)

Sets the startup grace period.

pub const fn start_period(&self) -> Option<&Sourced<HealthcheckDuration>>

Returns the startup grace period.

pub fn set_start_interval( &mut self, start_interval: Sourced<HealthcheckDuration>, )

Sets the check interval used during the startup grace period.

pub const fn start_interval(&self) -> Option<&Sourced<HealthcheckDuration>>

Returns the check interval used during the startup grace period.