pub struct Provenance { /* private fields */ }Expand description
Location from which a neutral-model value was derived.
Implementations
Sourceimpl Provenance
impl Provenance
Sourcepub const fn spanned(source: SourceId, span: SourceSpan) -> Self
pub const fn spanned(source: SourceId, span: SourceSpan) -> Self
Creates provenance for one byte range in a source.
Sourcepub const fn runtime_observation(source: SourceId) -> Self
pub const fn runtime_observation(source: SourceId) -> Self
Creates provenance for effective state observed from a runtime resource.
Sourcepub const fn user_override(source: SourceId) -> Self
pub const fn user_override(source: SourceId) -> Self
Creates provenance for an explicit caller or user override.
Sourcepub const fn implementation_default(source: SourceId) -> Self
pub const fn implementation_default(source: SourceId) -> Self
Creates provenance for a default introduced by a named implementation profile.
Sourcepub const fn conversion_decision(source: SourceId) -> Self
pub const fn conversion_decision(source: SourceId) -> Self
Creates provenance for a value chosen by an explicit conversion decision.
Sourcepub const fn kind(&self) -> ProvenanceKind
pub const fn kind(&self) -> ProvenanceKind
Returns how this origin entered the conversion plan.
Sourcepub const fn span(&self) -> Option<SourceSpan>
pub const fn span(&self) -> Option<SourceSpan>
Returns the optional byte range.