pub struct Sourced<T> { /* private fields */ }Expand description
A value and every source location that contributed to it.
Implementations
Sourceimpl<T> Sourced<T>
impl<T> Sourced<T>
Sourcepub const fn generated(value: T) -> Self
pub const fn generated(value: T) -> Self
Creates a value without source provenance, such as a generated default.
Sourcepub fn from_source(value: T, origin: Provenance) -> Self
pub fn from_source(value: T, origin: Provenance) -> Self
Creates a value with one source origin.
Sourcepub fn add_origin(&mut self, origin: Provenance)
pub fn add_origin(&mut self, origin: Provenance)
Adds another contributing origin in discovery order.
Sourcepub fn origins(&self) -> &[Provenance]
pub fn origins(&self) -> &[Provenance]
Returns all origins in discovery order.
Sourcepub fn into_parts(self) -> (T, Vec<Provenance>)
pub fn into_parts(self) -> (T, Vec<Provenance>)
Decomposes the sourced value.