#[non_exhaustive]pub enum ModelError {
Show 19 variants
EmptyValue(&'static str),
ContainsNul(&'static str),
ReversedSpan {
start: usize,
end: usize,
},
DuplicateResource {
kind: &'static str,
name: String,
},
DuplicateServiceGroupMember {
group: String,
service: String,
},
UnknownServiceGroupMember {
group: String,
service: String,
},
ServiceInMultipleGroups {
service: String,
existing: String,
replacement: String,
},
UnknownImageAcquisitionReference {
service: String,
acquisition: String,
},
UnknownImageBuildReference {
service: String,
build: String,
},
UnknownVolumeImageAcquisitionReference {
volume: String,
acquisition: String,
},
UnknownVolumeImageBuildReference {
volume: String,
build: String,
},
UnknownArtifactDependencyNode {
kind: &'static str,
name: String,
},
ImageArtifactDependencyCycle {
nodes: Vec<String>,
},
InvalidImageReference(&'static str),
ZeroContainerPort,
UnknownNetworkAttachmentIndex {
index: usize,
len: usize,
},
UnknownServiceGroupRuntimeNetworkIndex {
index: usize,
len: usize,
},
RootfsImageSourceConflict {
service: String,
source: &'static str,
},
InvalidHealthcheckRetries,
}Expand description
Error raised when constructing an invalid neutral model value.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EmptyValue(&'static str)
A required value was empty.
ContainsNul(&'static str)
A value contained a NUL byte.
ReversedSpan
A source byte range ended before it started.
DuplicateResource
An application already contains a resource of this kind and name.
DuplicateServiceGroupMember
A service was added to the same group more than once.
UnknownServiceGroupMember
A service group referenced a service absent from the application.
ServiceInMultipleGroups
A service was assigned to more than one application group.
Fields
UnknownImageAcquisitionReference
A service referenced an image acquisition absent from the application.
Fields
UnknownImageBuildReference
A service referenced an image build absent from the application.
UnknownVolumeImageAcquisitionReference
A volume referenced an image-acquisition resource absent from the application.
Fields
UnknownVolumeImageBuildReference
A volume referenced an image-build resource absent from the application.
UnknownArtifactDependencyNode
An explicitly supplied artifact dependency referred to a resource absent from the application.
ImageArtifactDependencyCycle
Explicit artifact dependencies formed a cycle.
InvalidImageReference(&'static str)
An image reference had invalid component structure.
ZeroContainerPort
A container port was zero.
UnknownNetworkAttachmentIndex
A requested service network-attachment index did not exist.
Fields
UnknownServiceGroupRuntimeNetworkIndex
A requested group-runtime network-attachment index did not exist.
Fields
RootfsImageSourceConflict
A service combined a root filesystem with an image source.
InvalidHealthcheckRetries
A health-check retry count was not a non-negative decimal integer.